@@ -94,13 +94,13 @@ class Energy(seamm.Node):
 
         return self.header + "\n" + __(text, **P, indent=4 * " ").__str__()
 
-    def get_input(self, calculation_type="energy"):
+    def get_input(self, calculation_type="energy", restart=None):
         """Get the input for an energy calculation for Psi4"""
         # Create the directory
         directory = Path(self.directory)
         directory.mkdir(parents=True, exist_ok=True)
 
-        # references = self.parent.references
+        _, configuration = self.get_system_configuration(None)
 
         P = self.parameters.current_values_to_dict(
             context=seamm.flowchart_variables._data
@@ -135,15 +135,29 @@ class Energy(seamm.Node):
         # lines.append('set scf_type df')
         # lines.append('set guess sad')
 
-        spin_restricted = P["spin-restricted"] == "yes"
+        multiplicity = configuration.spin_multiplicity
+        spin_restricted = P["spin-restricted"]
+        if spin_restricted == "default":
+            if multiplicity == 1:
+                restricted = True
+            else:
+                restricted = False
+        elif spin_restricted == "yes":
+            restricted = True
+        else:
+            restricted = False
+
         if method == "dft":
-            if spin_restricted:
+            if restricted:
                 lines.append("set reference rks")
             else:
                 lines.append("set reference uks")
         else:
-            if spin_restricted:
-                lines.append("set reference rhf")
+            if restricted:
+                if multiplicity == 1:
+                    lines.append("set reference rhf")
+                else:
+                    lines.append("set reference rohf")
             else:
                 lines.append("set reference uhf")
 
@@ -151,6 +165,38 @@ class Energy(seamm.Node):
             lines.append("set freeze_core True")
         else:
             lines.append("set freeze_core False")
+
+        if P["stability analysis"]:
+            lines.append("set stability_analysis True")
+
+        # Convergence parameters and methods
+        lines.append("set fail_on_maxiter False")  # Psi4 hangs! Cope in the plug-in
+
+        lines.append(f"set maxiter {P['maximum iterations']}")
+
+        if P["density convergence"] != "default":
+            lines.append(f"set d_convergence {P['density convergence']}")
+        if P["energy convergence"] != "default":
+            lines.append(f"set e_convergence {P['energy convergence']}")
+
+        if P["use damping"]:
+            lines.append(f"set damping_percentage {P['damping percentage']}")
+            lines.append(f"set damping_convergence {P['damping convergence']}")
+
+        if P["use level shift"]:
+            lines.append(f"set level_shift {P['level shift']}")
+            lines.append(f"set level_shift_cutoff {P['level shift convergence']}")
+
+        if P["use soscf"]:
+            lines.append("set soscf True")
+            lines.append(
+                f"set soscf_start_convergence {P['soscf starting convergence']}"
+            )
+            lines.append(f"set soscf_conv {P['soscf convergence']}")
+            lines.append(f"set soscf_max_iter {P['soscf max iterations']}")
+            if P["soscf print iterations"]:
+                lines.append("set soscf_print True")
+
         lines.append("")
         if method == "dft":
             if P["level"] == "recommended":
@@ -158,49 +204,79 @@ class Energy(seamm.Node):
             else:
                 functional_string = P["advanced_functional"]
             functional = psi4_step.dft_functionals[functional_string]["name"]
-            if len(psi4_step.dft_functionals[functional_string]["dispersion"]) > 1:
+            if (
+                P["dispersion"] != "none"
+                and len(psi4_step.dft_functionals[functional_string]["dispersion"]) > 1
+            ):
                 functional = functional + "-" + P["dispersion"]
-            lines.append(
-                f"Eelec, wfn = {calculation_type}('{functional}', " "return_wfn=True)"
-            )
+            if restart is None:
+                lines.append(
+                    f"Eelec, wfn = {calculation_type}('{functional}', return_wfn=True)"
+                )
+            else:
+                if calculation_type == "gradient":
+                    lines.append(
+                        f"Eelec, wfn = energy('{functional}', return_wfn=True,"
+                        f" restart_file='{restart}')"
+                    )
+                    lines.append(f"G = gradient('{functional}', ref_wfn=wfn)")
+                else:
+                    lines.append(
+                        f"Eelec, wfn = {calculation_type}('{functional}', "
+                        f"return_wfn=True, restart_file='{restart}')"
+                    )
         else:
-            lines.append(
-                f"Eelec, wfn = {calculation_type}('{method}', return_wfn=True)"
-            )
+            if restart is None:
+                lines.append(
+                    f"Eelec, wfn = {calculation_type}('{method}', return_wfn=True)"
+                )
+            else:
+                if calculation_type == "gradient":
+                    lines.append(
+                        f"Eelec, wfn = energy('{method}', return_wfn=True, "
+                        f" restart_file='{restart}')"
+                    )
+                    lines.append(f"G = gradient('{method}', ref_wfn=wfn)")
+                else:
+                    lines.append(
+                        f"Eelec, wfn = {calculation_type}('{method}', return_wfn=True, "
+                        f" restart_file='{restart}')"
+                    )
 
-        # Dump the properties to a json file
-        filename = f"@{self._id[-1]}+properties.json"
-        lines.append("")
-        lines.append("oeprop(")
-        lines.append("    wfn,")
-        lines.append("    'MULTIPOLE(5)',")
-        lines.append("    'ESP_AT_NUCLEI',")
-        # lines.append("    'MO_EXTENTS',")
-        lines.append("    'LOWDIN_CHARGES',")
-        lines.append("    'MULLIKEN_CHARGES',")
-        lines.append("    'WIBERG_LOWDIN_INDICES',")
-        lines.append("    'MAYER_INDICES',")
-        lines.append("    'NO_OCCUPATIONS',")
-        lines.append("    title='PROP'")
-        lines.append(")")
-        lines.append("")
-        lines.append("variables = scalar_variables()")
-        lines.append("variables.update(wfn.scalar_variables())")
-        lines.append("arrays = array_variables()")
-        lines.append("for item in arrays:")
-        lines.append("    variables[item] = array_variable(item).np.tolist()")
-        lines.append("arrays = wfn.array_variables()")
-        lines.append("for item in arrays:")
-        lines.append("    variables[item] = wfn.array_variable(item).np.tolist()")
-        lines.append("variables['Eelec'] = Eelec")
-        lines.append(f"variables['_method'] = '{method}'")
-        lines.append(f"variables['_method_string'] = '{method_string}'")
-        lines.append("")
-        lines.append("")
-        lines.append(f"with open('{filename}', 'w') as fd:")
-        lines.append(
-            "    json.dump(fix_multipoles(variables), fd, sort_keys=True, " "indent=3)"
-        )
+        if calculation_type != "gradient":
+            # Dump the properties to a json file
+            filename = f"@{self._id[-1]}+properties.json"
+            lines.append("")
+            lines.append("oeprop(")
+            lines.append("    wfn,")
+            lines.append("    'MULTIPOLE(5)',")
+            lines.append("    'ESP_AT_NUCLEI',")
+            # lines.append("    'MO_EXTENTS',")
+            lines.append("    'LOWDIN_CHARGES',")
+            lines.append("    'MULLIKEN_CHARGES',")
+            lines.append("    'WIBERG_LOWDIN_INDICES',")
+            lines.append("    'MAYER_INDICES',")
+            lines.append("    'NO_OCCUPATIONS',")
+            lines.append("    title='PROP'")
+            lines.append(")")
+            lines.append("")
+            lines.append("variables = scalar_variables()")
+            lines.append("variables.update(wfn.scalar_variables())")
+            lines.append("arrays = array_variables()")
+            lines.append("for item in arrays:")
+            lines.append("    variables[item] = array_variable(item).np.tolist()")
+            lines.append("arrays = wfn.array_variables()")
+            lines.append("for item in arrays:")
+            lines.append("    variables[item] = wfn.array_variable(item).np.tolist()")
+            lines.append("variables['Eelec'] = Eelec")
+            lines.append(f"variables['_method'] = '{method}'")
+            lines.append(f"variables['_method_string'] = '{method_string}'")
+            lines.append("")
+            lines.append("")
+            lines.append(f"with open('{filename}', 'w') as fd:")
+            lines.append(
+                "    json.dump(fix_multipoles(variables), fd, sort_keys=True, indent=3)"
+            )
         lines.append("")
 
         return "\n".join(lines)
@@ -235,5 +311,7 @@ class Energy(seamm.Node):
                 "\nThere are no results from Psi4. Perhaps it "
                 f"failed? Looking for {tmp}."
             )
+            printer.normal(__(text, **data, indent=self.indent + 4 * " "))
+            raise RuntimeError(text)
 
         printer.normal(__(text, **data, indent=self.indent + 4 * " "))
