@@ -54,7 +54,7 @@ class Optimization(psi4_step.Energy):
             added += " The convergence criterion is '{geometry convergence}'."
 
         if P["recalc hessian"] != "never":
-            added += " The Hessian will be recalculated every {recalc hession}"
+            added += " The Hessian will be recalculated every {recalc hessian}"
             added += " steps. Note that calculating the second derivatives is "
             added += "quite expensive!"
 
@@ -62,6 +62,8 @@ class Optimization(psi4_step.Energy):
 
     def get_input(self, calculation_type="optimize"):
         """Get the input for an optimization calculation for Psi4"""
+        _, configuration = self.get_system_configuration()
+
         # Create the directory
         directory = Path(self.directory)
         directory.mkdir(parents=True, exist_ok=True)
@@ -87,15 +89,41 @@ class Optimization(psi4_step.Energy):
         lines.append("#" * 80)
         lines.append("")
         lines.append("set opt_type min")
-        opt_method = psi4_step.optimization_methods[P["optimization method"]]
+        if P["optimization method"] in psi4_step.optimization_methods:
+            opt_method = psi4_step.optimization_methods[P["optimization method"]]
+        else:
+            opt_method = P["optimization method"]
         lines.append(f"set step_type {opt_method}")
-        max_steps = 50
+        lines.append(f"set opt_coordinates {P['coordinates']}")
+        max_steps = P["max geometry steps"]
+        if max_steps == "default":
+            max_steps = 6 * configuration.n_atoms
+        if "nAtoms" in max_steps:
+            n_atoms = configuration.n_atoms
+            max_steps = max_steps.replace("nAtoms", str(n_atoms))
+            max_steps = eval(max_steps)
+
         lines.append(f"set geom_maxiter {max_steps}")
         if P["geometry convergence"] == "Custom":
             pass
         else:
-            convergence = psi4_step.optimization_convergence[P["geometry convergence"]]
+            if P["geometry convergence"] in psi4_step.optimization_convergence:
+                convergence = psi4_step.optimization_convergence[
+                    P["geometry convergence"]
+                ]
+            else:
+                convergence = P["geometry convergence"]
             lines.append(f"set g_convergence {convergence}")
+
+        if P["recalc hessian"] == "every step":
+            lines.append("set full_hess_every 1")
+        elif P["recalc hessian"] == "at beginning":
+            lines.append("set full_hess_every 0")
+        elif P["recalc hessian"] == "never":
+            lines.append("set full_hess_every -1")
+        else:
+            lines.append(f"set full_hess_every {P['recalc hessian']}")
+        lines.append(f"set hess_update {P['hessian update']}")
         lines.append("")
 
         # Add in the input from the energy part of things
@@ -132,5 +160,7 @@ class Optimization(psi4_step.Energy):
                 "\nThere are no results from Psi4. Perhaps it "
                 f"failed? Looking for {str(json_file)}."
             )
+            printer.normal(__(text, **data, indent=self.indent + 4 * " "))
+            raise RuntimeError(text)
 
         printer.normal(__(text, **data, indent=self.indent + 4 * " "))
