@@ -19,16 +19,16 @@ class OptimizationParameters(psi4_step.EnergyParameters):
             "default": "Rational Function Optimization",
             "kind": "enumeration",
             "default_units": "",
-            "enumeration": [x for x in psi4_step.optimization_methods],
+            "enumeration": [*psi4_step.optimization_methods],
             "format_string": "s",
             "description": "Method:",
-            "help_text": ("The optimization method to use."),
+            "help_text": "The optimization method to use.",
         },
         "max geometry steps": {
-            "default": "default",
+            "default": "6*nAtoms",
             "kind": "integer",
             "default_units": "",
-            "enumeration": ("default",),
+            "enumeration": ("6*nAtoms",),
             "format_string": "",
             "description": "Maximum steps:",
             "help_text": (
@@ -50,7 +50,7 @@ class OptimizationParameters(psi4_step.EnergyParameters):
             "default": "never",
             "kind": "integer",
             "default_units": "",
-            "enumeration": ("never",),
+            "enumeration": ("every step", "at beginning", "never"),
             "format_string": "",
             "description": "Recalculate Hessian:",
             "help_text": (
@@ -58,6 +58,33 @@ class OptimizationParameters(psi4_step.EnergyParameters):
                 "values help convergence but are expensive."
             ),
         },
+        "hessian update": {
+            "default": "bfgs",
+            "kind": "enumeration",
+            "default_units": "",
+            "enumeration": (
+                "bfgs",
+                "ms",
+                "powell",
+                "none",
+            ),
+            "format_string": "s",
+            "description": "Hessian update:",
+            "help_text": "The algorithm for updating the Hessian.",
+        },
+        "coordinates": {
+            "default": "Internal",
+            "kind": "enumeration",
+            "default_units": "",
+            "enumeration": (
+                "Internal",
+                "Cartesian",
+                "Both",
+            ),
+            "format_string": "s",
+            "description": "Type of coordinates:",
+            "help_text": "The typ of coordinates to use in the minimization.",
+        },
     }
 
     def __init__(self, defaults={}, data=None):
