@@ -118,14 +118,14 @@ class TkOptimization(psi4_step.TkEnergy):
 
     def reset_dialog(self, widget=None):
         """Layout the widgets, letting our parents go first."""
-        row = super().reset_dialog()
+        rows = super().reset_dialog()
 
-        self["optimization"].grid(row=row, column=0)
-        row += 1
+        self["optimization"].grid(row=0, column=1, rowspan=rows, sticky=tk.N)
+        # row += 1
 
         self.reset_optimization()
 
-        return row
+        return rows
 
     def reset_optimization(self, widget=None):
         convergence = self["geometry convergence"].get()
@@ -142,6 +142,10 @@ class TkOptimization(psi4_step.TkEnergy):
         widgets.append(self["optimization method"])
         row += 1
 
+        self["coordinates"].grid(row=row, column=0, columnspan=2, sticky=tk.EW)
+        widgets.append(self["coordinates"])
+        row += 1
+
         self["max geometry steps"].grid(row=row, column=0, columnspan=2, sticky=tk.EW)
         widgets.append(self["max geometry steps"])
         row += 1
@@ -157,4 +161,8 @@ class TkOptimization(psi4_step.TkEnergy):
         widgets.append(self["recalc hessian"])
         row += 1
 
+        self["hessian update"].grid(row=row, column=0, columnspan=2, sticky=tk.EW)
+        widgets.append(self["hessian update"])
+        row += 1
+
         sw.align_labels(widgets)
